@@ -9,7 +9,7 @@ class BodyValidator(Validator):
     def get_violation_definitions(cls):
         return {
             'page.body.not_found': {
-                'title': 'Page body not found.',
+                'title': 'Page body not found',
                 'description': lambda value: 'Body was not found on %s.' % value,
                 'category': 'Semantics'
             }
